@@ -59,7 +59,7 @@ product_code = os.getenv("FastTrackerProductCode") or "fast"  # type: str
 # 服务编码 默认"analysis"
 app_code = os.getenv("FastTrackerAppCode") or "analysis"  # type: str
 # 上报地址 默认"udp://127.0.0.1:5140"
-collector_address = os.getenv("FastTrackerSocketPath") or "udp://only-fluent-bit:5140"  # type: str
+collector_address = os.getenv("FastTrackerSocketPath") or "udp://fluent-bit:5140"  # type: str
 # 缓冲区大小 默认1
 buffer_size = os.getenv("FastTrackerBufferSize") or 1  # type: int
 # 上报超时时间 默认1（秒）
